icometrix-SDK
=============

icometrix-SDK is a Software Development Kit (SDK) for Python, which allows Python developers to write software that
interacts with the icometrix API.

:Author: Jeroen Pinxten
:Organization: `icometrix <https://icometrix.com>`_
:Repository: https://github.com/icometrix/icometrix-sdk
:API documentation: https://icometrix.github.io/icometrix-sdk/index.html
